@@ -6,7 +6,7 @@
 ;; URL: http://github.com/s-kostyaev/elisa
 ;; Keywords: help local tools
 ;; Package-Requires: ((emacs "29.2") (ellama "0.11.2") (llm "0.18.1") (async "1.9.8") (plz "0.9"))
-;; Version: 1.1.2
+;; Version: 1.1.3
 ;; SPDX-License-Identifier: GPL-3.0-or-later
 ;; Created: 18th Feb 2024
 
@@ -1368,6 +1368,19 @@ It does nothing if buffer file not inside one of existing collections."
 		     "SELECT name FROM collections;")))))))
     (push col elisa-enabled-collections)))
 
+;;;###autoload
+(defun elisa-enable-all-collections ()
+  "Enable all collections."
+  (interactive)
+  (let ((all-collections
+	 (flatten-tree
+	  (sqlite-select
+	   elisa-db
+	   "SELECT DISTINCT name FROM collections;"))))
+    (setq elisa-enabled-collections
+	  (cl-set-difference all-collections elisa-enabled-collections :test #'string=))
+    (mapc #'elisa-enable-collection all-collections)))
+
 ;;;###autoload
 (defun elisa-create-empty-collection (&optional collection)
   "Create new empty COLLECTION."
